"""Module for defining constants used in the `Menu` widget."""

from kivy.lang.builder import Builder

from ubo_gui.page import PAGE_MAX_ITEMS

PAGE_SIZE = PAGE_MAX_ITEMS
SHORT_WIDTH = 46
MENU_ITEM_HEIGHT = 52
MENU_ITEM_GAP = 7

Builder.load_string(
    f"""
#:set UBO_GUI_PAGE_SIZE {PAGE_SIZE}
#:set UBO_GUI_SHORT_WIDTH {SHORT_WIDTH}
#:set UBO_GUI_MENU_ITEM_HEIGHT {MENU_ITEM_HEIGHT}
#:set UBO_GUI_MENU_ITEM_GAP {MENU_ITEM_GAP}
""",
)



"""Module to store constants used in the application."""

from kivy.lang.builder import Builder

PRIMARY_COLOR = '#68B7FF'
SECONDARY_COLOR = '#363F4B'
SECONDARY_COLOR_LIGHT = '#ABA7A7'
TEXT_COLOR = '#FFFFFF'

INFO_COLOR = '#2196F3'
DANGER_COLOR = '#FF3F51'
WARNING_COLOR = '#FFC107'
SUCCESS_COLOR = '#03F7AE'

Builder.load_string(
    f"""
#:set UBO_GUI_PRIMARY_COLOR '{PRIMARY_COLOR}'
#:set UBO_GUI_SECONDARY_COLOR '{SECONDARY_COLOR}'
#:set UBO_GUI_SECONDARY_COLOR_LIGHT '{SECONDARY_COLOR_LIGHT}'
#:set UBO_GUI_TEXT_COLOR '{TEXT_COLOR}'

#:set UBO_GUI_INFO_COLOR '{INFO_COLOR}'
#:set UBO_GUI_DANGER_COLOR '{DANGER_COLOR}'
#:set UBO_GUI_WARNING_COLOR '{WARNING_COLOR}'
#:set UBO_GUI_SUCCESS_COLOR '{SUCCESS_COLOR}'
""",
)



"""Module for the `NormalMenuPageWidget` class."""

from __future__ import annotations

import pathlib
from typing import TYPE_CHECKING, Sequence

from kivy.lang.builder import Builder

from ubo_gui.page import PageWidget

from .item_widget import ItemWidget

if TYPE_CHECKING:
    from ubo_gui.menu.types import Item


class NormalMenuPageWidget(PageWidget):
    """renders a normal page of a `Menu`."""

    def __init__(
        self: PageWidget,
        items: Sequence[Item | None] | None = None,
        *args: object,
        **kwargs: object,
    ) -> None:
        """Initialize `NormalMenuPageWidget`."""
        self.bind(on_kv_post=self.render)
        super().__init__(items, *args, **kwargs)
        self.bind(items=self.render)

    def render(self: NormalMenuPageWidget, *_: object) -> None:
        """Render the widget."""
        self.ids.layout.clear_widgets()
        for i in range(self.count):
            self.ids.layout.add_widget(
                ItemWidget(
                    item=self.items[i] if i < len(self.items) else None,
                    size_hint=(1, None),
                ),
            )


Builder.load_file(
    pathlib.Path(__file__)
    .parent.joinpath('normal_menu_page_widget.kv')
    .resolve()
    .as_posix(),
)
